function [k, X, Y, pasos, distancias, sal1, sal2] = te(F, signoX, signoXF, algoritmo, par1, par2)
%te
%   [k, X, Y] = te(F)
%
%   Resuelve la Teoría de la explotación
%      Max 
%      X (D-C+k(W-V)) ~ 0 <-> -Y ~ 0                X (D-C+k(W-V)) .* Y = 0
%      X ~ 0              <-> (D-C+k(W-V)) Y ~ 0    X .* (D-C+k(W-V)) Y = 0
%      k > 0                  1 + X (W-V) Y = 0
%   Los procesos deben escribirse como
%      F(:,:,1) = W - V
%      F(:,:,2) = D - C
%
%   [k, X, Y, pasos, distancias] = te(F, signoX, signoXF, algoritmo)
%      F           procesos de producción
%      signoX      signo de las intensidades; por defecto X >= 0
%      signoXF     signo de los balances materiales; por defecto X(D-C+k(W-V))=0
%      algoritmo   especifica el algoritmo que se usará
%      k           factor de explotación
%      X           intensidades-trabajo
%      Y           valores-trabajo
%      pasos       número de iteraciones efectuadas
%      distancias  distancia de la solución a las condiciones
%
%   Esta función opera usando vn y normalizando los valores-trabajo. Véase
%   la ayuda de vn.

if nargin < 2, signoX = []; end
if nargin < 3, signoXF = []; end
if nargin < 4, algoritmo = []; end
if nargin < 5, par1 = []; end
if nargin < 6, par2 = []; end

[k, X, Y, pasos, distancias, sal1, sal2] = vn(F, signoX, signoXF, algoritmo, par1, par2);
for c1 = 1:size(k,2)
    Y(:,c1) = Y(:,c1) ./ k(c1);
    distancias(:, [2,3], c1) = distancias(:, [2,3], c1) ./ k(c1);
end